#[repr(transparent)]pub struct Ffroctl1(pub u32);Expand description
FFRO control 1
Tuple Fields
0: u32Implementations
Sourceimpl Ffroctl1
impl Ffroctl1
Sourcepub const fn update(&self) -> Update
pub const fn update(&self) -> Update
Update Safe Mode Control. In order to change any of the TRIM values, the user first needs to set the update safe mode bit, then proceed to change the respective TRIM values needed, followed by clearing the update safe mode bit.
Sourcepub const fn set_update(&mut self, val: Update)
pub const fn set_update(&mut self, val: Update)
Update Safe Mode Control. In order to change any of the TRIM values, the user first needs to set the update safe mode bit, then proceed to change the respective TRIM values needed, followed by clearing the update safe mode bit.