#[repr(transparent)]pub struct Syscpuahbclkdiv(pub u32);Expand description
system cpu AHB clock divider
Tuple Fields
0: u32Implementations
Sourceimpl Syscpuahbclkdiv
impl Syscpuahbclkdiv
Sourcepub const fn div(&self) -> u8
pub const fn div(&self) -> u8
Clock Divider Value Selection. . . 0: Divide by 1. … 255: Divide by 256.
Sourcepub const fn set_div(&mut self, val: u8)
pub const fn set_div(&mut self, val: u8)
Clock Divider Value Selection. . . 0: Divide by 1. … 255: Divide by 256.
Sourcepub const fn reqflag(&self) -> bool
pub const fn reqflag(&self) -> bool
Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.
Sourcepub const fn set_reqflag(&mut self, val: bool)
pub const fn set_reqflag(&mut self, val: bool)
Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.