nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Syspll0ctl0

Struct Syspll0ctl0 

#[repr(transparent)]
pub struct Syspll0ctl0(pub u32);
system pll0 control0

Tuple Fields

0: u32

Implementations

Source

impl Syspll0ctl0

pub const fn bypass(&self) -> Bypass

SYSPLL0 BYPASS Mode

pub const fn set_bypass(&mut self, val: Bypass)

SYSPLL0 BYPASS Mode

pub const fn reset(&self) -> Reset

SYSPLL0 Reset:

pub const fn set_reset(&mut self, val: Reset)

SYSPLL0 Reset:

pub const fn holdringoff_ena(&self) -> HoldringoffEna

Hold Ring Off Control: This bit is used to avoid multi wave within the VCO.

pub const fn set_holdringoff_ena(&mut self, val: HoldringoffEna)

Hold Ring Off Control: This bit is used to avoid multi wave within the VCO.

pub const fn mult(&self) -> Mult

Multiplication Factor for FSYSPLL0_OUTPUT:

pub const fn set_mult(&mut self, val: Mult)

Multiplication Factor for FSYSPLL0_OUTPUT: