nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Usbhsfclkdiv

Struct Usbhsfclkdiv 

#[repr(transparent)]
pub struct Usbhsfclkdiv(pub u32);
USBHS Fclk divider

Tuple Fields

0: u32

Implementations

Source

impl Usbhsfclkdiv

pub const fn div(&self) -> u8

Clock Divider Value Selection. . . 0: Divide by 1. … 255: Divide by 256.

pub const fn set_div(&mut self, val: u8)

Clock Divider Value Selection. . . 0: Divide by 1. … 255: Divide by 256.

pub const fn reset(&self) -> bool

Resets the divider counter. Can be used to make sure a new divider value is used right away rather than completing the previous count.

pub const fn set_reset(&mut self, val: bool)

Resets the divider counter. Can be used to make sure a new divider value is used right away rather than completing the previous count.

pub const fn halt(&self) -> bool

Halts the divider counter. The intent is to allow the divider clock source to be changed without the risk of a glitch at the output.

pub const fn set_halt(&mut self, val: bool)

Halts the divider counter. The intent is to allow the divider clock source to be changed without the risk of a glitch at the output.

pub const fn reqflag(&self) -> bool

Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.

pub const fn set_reqflag(&mut self, val: bool)

Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.