nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Wakeclk32khzsel

Struct Wakeclk32khzsel 

#[repr(transparent)]
pub struct Wakeclk32khzsel(pub u32);
32k wake clock selection

Tuple Fields

0: u32

Implementations

Source

impl Wakeclk32khzsel

pub const fn sel(&self) -> Wakeclk32khzselSel

32KHz Wake Clock Low Power Functional Clock Source Selection. . .

pub const fn set_sel(&mut self, val: Wakeclk32khzselSel)

32KHz Wake Clock Low Power Functional Clock Source Selection. . .