#[repr(transparent)]pub struct Syspll0ctl0(pub u32);Expand description
system pll0 control0
Tuple Fields
0: u32Implementations
Sourceimpl Syspll0ctl0
impl Syspll0ctl0
Sourcepub const fn set_bypass(&mut self, val: Bypass)
pub const fn set_bypass(&mut self, val: Bypass)
SYSPLL0 BYPASS Mode
Sourcepub const fn holdringoff_ena(&self) -> HoldringoffEna
pub const fn holdringoff_ena(&self) -> HoldringoffEna
Hold Ring Off Control: This bit is used to avoid multi wave within the VCO.
Sourcepub const fn set_holdringoff_ena(&mut self, val: HoldringoffEna)
pub const fn set_holdringoff_ena(&mut self, val: HoldringoffEna)
Hold Ring Off Control: This bit is used to avoid multi wave within the VCO.