#[repr(transparent)]pub struct Wakeclk32khzsel(pub u32);Expand description
32k wake clock selection
Tuple Fields
0: u32Implementations
Sourceimpl Wakeclk32khzsel
impl Wakeclk32khzsel
Sourcepub const fn sel(&self) -> Wakeclk32khzselSel
pub const fn sel(&self) -> Wakeclk32khzselSel
32KHz Wake Clock Low Power Functional Clock Source Selection. . .
Sourcepub const fn set_sel(&mut self, val: Wakeclk32khzselSel)
pub const fn set_sel(&mut self, val: Wakeclk32khzselSel)
32KHz Wake Clock Low Power Functional Clock Source Selection. . .